@@ -12,7 +12,7 @@ def dfslow():   #检查比较慢的映射
         开始时间=time.time()
         os.system("df "+挂载目录+">/dev/null")
         if time.time()-开始时间>1:
-            print(挂载目标,挂载目录,time.time()-bt)
+            print(挂载目标,挂载目录,time.time()-开始时间)
 
 if __name__ == "__main__":
     dfslow()
